===================
pychemcurv.analysis
===================

.. automodule:: pychemcurv.analysis

CurvatureAnalyzer class
-----------------------

.. autoclass:: pychemcurv.analysis.CurvatureAnalyzer
    :members:

